@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Arrangement_on_surface_2/include/CGAL/Arr_rational_function_traits_2.h $
-// $Id: include/CGAL/Arr_rational_function_traits_2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Arrangement_on_surface_2/include/CGAL/Arr_rational_function_traits_2.h $
+// $Id: include/CGAL/Arr_rational_function_traits_2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Oren Salzman <orenzalz@post.tau.ac.il >
@@ -26,8 +26,6 @@
 #include <CGAL/Arr_rat_arc/Rational_arc_d_1.h>
 #include <CGAL/Arr_rat_arc/Cache.h>
 
-
-
 namespace CGAL {
 
 /*! \class
@@ -161,7 +159,7 @@ public:
     /*! The traits */
     const Traits* _traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits
      */
     Construct_x_monotone_curve_2(const Traits* traits) : _traits(traits) {}
@@ -299,7 +297,7 @@ public:
     /*! The traits */
     const Traits* _traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits
      */
     Construct_curve_2(const Traits* traits) : _traits(traits) {}
@@ -424,7 +422,7 @@ public:
     /*! The traits */
     const Traits* _traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits
      */
     Construct_point_2(const Traits* traits) : _traits(traits) {}
@@ -502,8 +500,7 @@ public:
   class Compare_x_2
   {
   public:
-    /*!
-     * Compare the x-coordinates of two points.
+    /*! compares the x-coordinates of two points.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return LARGER if x(p1) > x(p2);
@@ -517,7 +514,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_x_2 functor object. */
+  /*! obtains a Compare_x_2 functor object. */
   Compare_x_2 compare_x_2_object() const
   {
     return Compare_x_2();
@@ -533,7 +530,7 @@ public:
     /*! The traits */
     const Traits* _traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits
      */
     Compare_xy_2(const Traits* traits) : _traits(traits) {}
@@ -541,8 +538,7 @@ public:
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
 
   public:
-    /*!
-     * Compares two points lexigoraphically: by x, then by y.
+    /*! compares two points lexigoraphically: by x, then by y.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return LARGER if x(p1) > x(p2), or if x(p1) = x(p2) and y(p1) > y(p2);
@@ -555,7 +551,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_xy_2 functor object. */
+  /*! obtains a Compare_xy_2 functor object. */
   Compare_xy_2 compare_xy_2_object() const
   {
     return Compare_xy_2(this);
@@ -565,8 +561,7 @@ public:
   class Construct_min_vertex_2
   {
   public:
-    /*!
-     * Get the left endpoint of the x-monotone curve (segment).
+    /*! obtains the left endpoint of the x-monotone curve (segment).
      * \param cv The curve.
      * \return The left endpoint.
      */
@@ -576,7 +571,7 @@ public:
     }
   };
 
-  /*! Obtain a Construct_min_vertex_2 functor object. */
+  /*! obtains a Construct_min_vertex_2 functor object. */
   Construct_min_vertex_2 construct_min_vertex_2_object() const
   {
     return Construct_min_vertex_2();
@@ -586,8 +581,7 @@ public:
   class Construct_max_vertex_2
   {
   public:
-    /*!
-     * Get the right endpoint of the x-monotone curve (segment).
+    /*! obtains the right endpoint of the x-monotone curve (segment).
      * \param cv The curve.
      * \return The right endpoint.
      */
@@ -597,7 +591,7 @@ public:
     }
   };
 
-  /*! Obtain a Construct_max_vertex_2 functor object. */
+  /*! obtains a Construct_max_vertex_2 functor object. */
   Construct_max_vertex_2 construct_max_vertex_2_object() const
   {
     return Construct_max_vertex_2();
@@ -607,8 +601,7 @@ public:
   class Is_vertical_2
   {
   public:
-    /*!
-     * Check whether the given x-monotone curve is a vertical segment.
+    /*! checks whether the given x-monotone curve is a vertical segment.
      * \param cv The curve.
      * \return (true) if the curve is a vertical segment; (false) otherwise.
      */
@@ -619,7 +612,7 @@ public:
     }
   };
 
-  /*! Obtain an Is_vertical_2 functor object. */
+  /*! obtains an Is_vertical_2 functor object. */
   Is_vertical_2 is_vertical_2_object() const
   {
     return Is_vertical_2();
@@ -632,10 +625,11 @@ public:
   {
   private:
     Cache& _cache;
+
   public:
     Compare_y_at_x_2(Cache& cache) : _cache(cache) {}
-    /*!
-     * Return the location of the given point with respect to the input curve.
+
+    /*! returns the location of the given point with respect to the input curve.
      * \param cv The curve.
      * \param p The point.
      * \pre p is in the x-range of cv.
@@ -650,7 +644,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_y_at_x_2 functor object. */
+  /*! obtains a Compare_y_at_x_2 functor object. */
   Compare_y_at_x_2 compare_y_at_x_2_object () const
   {
     return Compare_y_at_x_2(_cache);
@@ -665,9 +659,9 @@ public:
     Cache& _cache;
 
   public:
-    Compare_y_at_x_left_2(Cache& cache) :_cache(cache) {}
-    /*!
-     * Compares the y value of two x-monotone curves immediately to the left
+    Compare_y_at_x_left_2(Cache& cache) : _cache(cache) {}
+
+    /*! compares the y value of two x-monotone curves immediately to the left
      * of their intersection point.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
@@ -697,7 +691,7 @@ public:
       return cv1.compare_at_intersection (cv2,p,true,_cache);}
   };
 
-  /*! Obtain a Compare_y_at_x_left_2 functor object. */
+  /*! obtains a Compare_y_at_x_left_2 functor object. */
   Compare_y_at_x_left_2 compare_y_at_x_left_2_object() const
   {
     return Compare_y_at_x_left_2(_cache);
@@ -713,8 +707,8 @@ public:
 
   public:
     Compare_y_at_x_right_2(Cache& cache) :_cache(cache) {}
-    /*!
-     * Compares the y value of two x-monotone curves immediately to the right
+
+    /*! compares the y value of two x-monotone curves immediately to the right
      * of their intersection point.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
@@ -747,7 +741,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_y_at_x_right_2 functor object. */
+  /*! obtains a Compare_y_at_x_right_2 functor object. */
   Compare_y_at_x_right_2 compare_y_at_x_right_2_object () const
   {
     return Compare_y_at_x_right_2(_cache);
@@ -762,7 +756,7 @@ public:
     /*! The traits */
     const Traits* _traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits
      */
     Equal_2(const Traits* traits) : _traits(traits) {}
@@ -770,8 +764,7 @@ public:
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
 
   public:
-    /*!
-     * Check if the two x-monotone curves are the same (have the same graph).
+    /*! checks if the two x-monotone curves are the same (have the same graph).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \return (true) if the two curves are the same; (false) otherwise.
@@ -785,8 +778,7 @@ public:
       return (cv1.equals(cv2));
     }
 
-    /*!
-     * Check if the two points are the same.
+    /*! checks if the two points are the same.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return (true) if the two point are the same; (false) otherwise.
@@ -802,7 +794,7 @@ public:
     }
   };
 
-  /*! Obtain an Equal_2 functor object. */
+  /*! obtains an Equal_2 functor object. */
   Equal_2 equal_2_object() const
   {
     return Equal_2(this);
@@ -816,7 +808,7 @@ public:
    */
   class Make_x_monotone_2 {
   public:
-    /*! Subdivide a given rational-function curve into x-monotone subcurves
+    /*! subdivides a given rational-function curve into x-monotone subcurves
      * and insert them to a given output iterator.
      * \param cv the curve.
      * \param oi the output iterator for the result. Its dereference type is a
@@ -840,7 +832,7 @@ public:
     }
   };
 
-  /*! Obtain a Make_x_monotone_2 functor object. */
+  /*! obtains a Make_x_monotone_2 functor object. */
   Make_x_monotone_2 make_x_monotone_2_object() const
   { return Make_x_monotone_2(); }
 
@@ -852,8 +844,7 @@ public:
 
   public:
     Split_2(Cache& cache) : _cache(cache) {}
-    /*!
-     * Split a given x-monotone curve at a given point into two sub-curves.
+    /*! splits a given x-monotone curve at a given point into two sub-curves.
      * \param cv The curve to split
      * \param p The split point.
      * \param c1 Output: The left resulting subcurve (p is its right endpoint).
@@ -867,7 +858,7 @@ public:
     }
   };
 
-  /*! Obtain a Split_2 functor object. */
+  /*! obtains a Split_2 functor object. */
   Split_2 split_2_object() const
   {
     return Split_2(_cache);
@@ -880,8 +871,7 @@ public:
     Cache& _cache;
   public:
     Intersect_2(Cache& cache) : _cache(cache) {}
-    /*!
-     * Find the intersections of the two given curves and insert them to the
+    /*! finds the intersections of the two given curves and insert them to the
      * given output iterator. As two segments may itersect only once, only a
      * single will be contained in the iterator.
      * \param cv1 The first curve.
@@ -898,7 +888,7 @@ public:
     }
   };
 
-  /*! Obtain an Intersect_2 functor object. */
+  /*! obtains an Intersect_2 functor object. */
   Intersect_2 intersect_2_object() const
   {
     return Intersect_2(_cache);
@@ -908,8 +898,7 @@ public:
   class Are_mergeable_2
   {
   public:
-    /*!
-     * Check whether it is possible to merge two given x-monotone curves.
+    /*! checks whether it is possible to merge two given x-monotone curves.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \return (true) if the two curves are mergeable - if they are supported
@@ -922,7 +911,7 @@ public:
     }
   };
 
-  /*! Obtain an Are_mergeable_2 functor object. */
+  /*! obtains an Are_mergeable_2 functor object. */
   Are_mergeable_2 are_mergeable_2_object() const
   {
     return Are_mergeable_2();
@@ -939,7 +928,7 @@ public:
     /*! The traits (in case it has state) */
     const Traits* m_traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits (in case it has state)
      */
     Merge_2(const Traits* traits) : m_traits(traits) {}
@@ -947,8 +936,7 @@ public:
     friend class Arr_rational_function_traits_2<Algebraic_kernel_d_1>;
 
   public:
-    /*!
-     * Merge two given x-monotone curves into a single curve (segment).
+    /*! merges two given x-monotone curves into a single curve (segment).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \param c Output: The merged curve.
@@ -965,7 +953,7 @@ public:
     }
   };
 
-  /*! Obtain a Merge_2 functor object. */
+  /*! obtains a Merge_2 functor object. */
   Merge_2 merge_2_object() const
   {
     return Merge_2(this);
@@ -981,7 +969,7 @@ public:
    */
   class Parameter_space_in_x_2 {
   public:
-    /*! Obtains the parameter space at the end of a line along the x-axis.
+    /*! obtains the parameter space at the end of a line along the x-axis.
      * \param xcv the line
      * \param ce the line end indicator:
      *     ARR_MIN_END - the minimal end of xc or
@@ -1000,7 +988,7 @@ public:
         xcv.left_parameter_space_in_x() : xcv.right_parameter_space_in_x();
     }
 
-    /*! Obtains the parameter space at a point along the x-axis.
+    /*! obtains the parameter space at a point along the x-axis.
      * \param p the point.
      * \return the parameter space at p.
      */
@@ -1010,7 +998,7 @@ public:
     }
   };
 
-  /*! Obtain a Parameter_space_in_x_2 function object */
+  /*! obtains a Parameter_space_in_x_2 function object */
   Parameter_space_in_x_2 parameter_space_in_x_2_object() const
   { return Parameter_space_in_x_2(); }
 
@@ -1019,7 +1007,7 @@ public:
    */
   class Parameter_space_in_y_2 {
   public:
-    /*! Obtains the parameter space at the end of a line along the y-axis .
+    /*! obtains the parameter space at the end of a line along the y-axis .
      * Note that if the line end coincides with a pole, then unless the line
      * coincides with the identification arc, the line end is considered to
      * be approaching the boundary, but not on the boundary.
@@ -1043,7 +1031,7 @@ public:
         xcv.left_parameter_space_in_y() : xcv.right_parameter_space_in_y();
     }
 
-    /*! Obtains the parameter space at a point along the y-axis.
+    /*! obtains the parameter space at a point along the y-axis.
      * \param p the point.
      * \return the parameter space at p.
      */
@@ -1053,7 +1041,7 @@ public:
     }
   };
 
-  /*! Obtain a Parameter_space_in_y_2 function object */
+  /*! obtains a Parameter_space_in_y_2 function object */
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(); }
 
@@ -1063,7 +1051,7 @@ public:
    */
   class Compare_x_near_boundary_2 {
   public:
-    /*! Compare the x-coordinate of a point with the x-coordinate of
+    /*! compares the x-coordinate of a point with the x-coordinate of
      * a line end near the boundary at y = +/- oo.
      * \param p the point direction.
      * \param xcv the line, the endpoint of which is compared.
@@ -1087,7 +1075,7 @@ public:
       return (r == NEGATIVE) ? POSITIVE : NEGATIVE ;
     }
 
-    /*! Compare the x-coordinates of 2 arcs ends near the boundary of the
+    /*! compares the x-coordinates of 2 arcs ends near the boundary of the
      * parameter space at y = +/- oo.
      * \param xcv1 the first arc.
      * \param ce1 the first arc end indicator -
@@ -1113,7 +1101,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_x_near_boundary_2 function object */
+  /*! obtains a Compare_x_near_boundary_2 function object */
   Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
   { return Compare_x_near_boundary_2(); }
 #endif
@@ -1127,7 +1115,7 @@ public:
     Cache& _cache;
 
   public:
-    /*! Compare the y-coordinates of 2 lines at their ends near the boundary
+    /*! compares the y-coordinates of 2 lines at their ends near the boundary
      * of the parameter space at x = +/- oo.
      * \param xcv1 the first arc.
      * \param xcv2 the second arc.
@@ -1147,7 +1135,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_y_near_boundary_2 function object */
+  /*! obtains a Compare_y_near_boundary_2 function object */
   Compare_y_near_boundary_2 compare_y_near_boundary_2_object() const
   { return Compare_y_near_boundary_2(_cache); }
 
@@ -1158,7 +1146,7 @@ public:
   class Compare_x_on_boundary_2
   {
    public:
-    /*! Compares the x coordinate of p with the curve end
+    /*! compares the x coordinate of p with the curve end
      * of xcv that is defined by ce at its limit.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
      */
@@ -1171,7 +1159,8 @@ public:
       return CGAL::compare(p.x(),
                            (ce == ARR_MIN_END) ? xcv.left_x() : xcv.right_x());
     }
-    /*! Compares the curve end of  xcv1 that is defined by ce1
+
+    /*! compares the curve end of  xcv1 that is defined by ce1
      *  with the curve end of xcv2 that is defined by ce2
      * at their limits in x.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
@@ -1192,7 +1181,7 @@ public:
 
   }; //Compare_x_on_boundary_2
 
-  /*! Obtain a Compare_x_on_boundary_2 function object */
+  /*! obtains a Compare_x_on_boundary_2 function object */
   Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
   { return Compare_x_on_boundary_2(); }
   //@}
@@ -1208,7 +1197,8 @@ public:
 
   public:
     Compare_x_near_boundary_2(Cache& cache) : _cache(cache) {}
-    /*! Compares the curve end of  xcv1 that is defined by ce1
+
+    /*! compares the curve end of  xcv1 that is defined by ce1
      *  with the curve end of xcv2 that is defined by ce2
      * at their limits in x.
      * Returns SMALLER, EQUAL, or LARGER accordingly.
@@ -1221,16 +1211,14 @@ public:
     }
   }; //Compare_x_near_boundary_2
 
-  /*! Obtain a Compare_x_near_boundary_2 function object */
+  /*! obtains a Compare_x_near_boundary_2 function object */
   Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
   { return Compare_x_near_boundary_2(_cache); }
 
   class Compare_endpoints_xy_2
   {
   public:
-
-    /*!
-     * Compare the endpoints of an $x$-monotone curve lexicographically.
+    /*! compares the endpoints of an $x$-monotone curve lexicographically.
      * (assuming the curve has a designated source and target points).
      * \param cv The curve.
      * \return SMALLER if the curve is directed right;
@@ -1245,7 +1233,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_endpoints_xy_2 functor object. */
+  /*! obtains a Compare_endpoints_xy_2 functor object. */
   Compare_endpoints_xy_2 compare_endpoints_xy_2_object() const
   {
     return Compare_endpoints_xy_2();
@@ -1254,9 +1242,7 @@ public:
   class Construct_opposite_2
   {
   public:
-
-    /*!
-     * Construct an opposite x-monotone (with swapped source and target).
+    /*! constructs an opposite x-monotone (with swapped source and target).
      * \param cv The curve.
      * \return The opposite curve.
      */
@@ -1266,7 +1252,7 @@ public:
     }
   };
 
-  /*! Obtain a Construct_opposite_2 functor object. */
+  /*! obtains a Construct_opposite_2 functor object. */
   Construct_opposite_2 construct_opposite_2_object() const
   {
     return Construct_opposite_2();
@@ -1300,10 +1286,10 @@ public:
   {
     _cache.cleanup();
   }
-}; //Arr_rational_function_traits_2
+}; // Arr_rational_function_traits_2
 
-}   //namespace CGAL {
+}  // namespace CGAL {
 
 #include <CGAL/enable_warnings.h>
 
-#endif  //CGAL_ARR_RATIONAL_ARC_TRAITS_D_1_H
+#endif
