@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org);
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Stream_support/include/CGAL/IO/PLY/PLY_reader.h $
-// $Id: include/CGAL/IO/PLY/PLY_reader.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Stream_support/include/CGAL/IO/PLY/PLY_reader.h $
+// $Id: include/CGAL/IO/PLY/PLY_reader.h 08b27d3db14 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
@@ -783,7 +783,7 @@ bool read_PLY_faces(std::istream& in,
 } // namespace PLY
 } // namespace internal
 
-#ifndef CGAL_NO_DEPREACTED_CODE
+#ifndef CGAL_NO_DEPRECATED_CODE
 using IO::PLY_property;
 using IO::make_ply_normal_reader;
 using IO::make_ply_normal_writer;
