@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Spatial_searching/include/CGAL/Kd_tree_node.h $
-// $Id: include/CGAL/Kd_tree_node.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Spatial_searching/include/CGAL/Kd_tree_node.h $
+// $Id: include/CGAL/Kd_tree_node.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -22,7 +22,7 @@
 #include <CGAL/Compact_container.h>
 #include <CGAL/Has_member.h>
 #include <CGAL/Spatial_searching/internal/Search_helpers.h>
-#include <boost/cstdint.hpp>
+#include <cstdint>
 
 namespace CGAL {
 
