@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Nef_2/include/CGAL/Nef_2/Polynomial.h $
-// $Id: include/CGAL/Nef_2/Polynomial.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Nef_2/include/CGAL/Nef_2/Polynomial.h $
+// $Id: include/CGAL/Nef_2/Polynomial.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -397,7 +397,7 @@ template <class pNT> class Polynomial :
   If |Number_type_traits<NT>::Has_gcd == Tag_true| then the division is
   done by \emph{pseudo division} based on a |gcd| operation of |NT|.  If
   |Number_type_traits<NT>::Has_gcd == Tag_false| then the division is done
-  by \emph{euclidean division} based on the division operation of the
+  by \emph{Euclidean division} based on the division operation of the
   field |NT|.
 
   \textbf{Note} that |NT=int| quickly leads to overflow
@@ -718,7 +718,7 @@ class Polynomial<int> :
   If |Number_type_traits<int>::Has_gcd == Tag_true| then the division is
   done by \emph{pseudo division} based on a |gcd| operation of |int|.  If
   |Number_type_traits<int>::Has_gcd == Tag_false| then the division is done
-  by \emph{euclidean division} based on the division operation of the
+  by \emph{Euclidean division} based on the division operation of the
   field |int|.
 
   \textbf{Note} that |int=int| quickly leads to overflow
@@ -1018,7 +1018,7 @@ determines the sign for the limit process $x \rightarrow \infty$.
   If |Number_type_traits<double>::Has_gcd == Tag_true| then the division is
   done by \emph{pseudo division} based on a |gcd| operation of |double|.  If
   |Number_type_traits<double>::Has_gcd == Tag_false| then the division is done
-  by \emph{euclidean division} based on the division operation of the
+  by \emph{Euclidean division} based on the division operation of the
   field |double|.
 
   \textbf{Note} that |double=int| quickly leads to overflow
