@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/interpolated_corrected_curvatures.h $
-// $Id: include/CGAL/Polygon_mesh_processing/interpolated_corrected_curvatures.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/interpolated_corrected_curvatures.h $
+// $Id: include/CGAL/Polygon_mesh_processing/interpolated_corrected_curvatures.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -622,7 +622,7 @@ void interpolated_corrected_curvatures_one_vertex(
   using parameters::get_parameter;
   using parameters::is_default_parameter;
 
-  Vertex_position_map vpm = choose_parameter(get_parameter(np, CGAL::vertex_point),
+  Vertex_position_map vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
     get_const_property_map(CGAL::vertex_point, pmesh));
 
   Vertex_normal_map vnm = choose_parameter(get_parameter(np, internal_np::vertex_normal_map),
@@ -773,7 +773,7 @@ private:
     using parameters::get_parameter;
     using parameters::is_default_parameter;
 
-    vpm = choose_parameter(get_parameter(np, CGAL::vertex_point),
+    vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
       get_const_property_map(CGAL::vertex_point, pmesh));
 
     vnm = choose_parameter(get_parameter(np, internal_np::vertex_normal_map),
