@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/refine_with_plane.h $
-// $Id: include/CGAL/Polygon_mesh_processing/refine_with_plane.h b26b07a1242 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/refine_with_plane.h $
+// $Id: include/CGAL/Polygon_mesh_processing/refine_with_plane.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -427,10 +427,16 @@ void refine_with_plane(PolygonMesh& pm,
     for (halfedge_descriptor h : halfedges_around_target(hv, pm))
     {
       if (is_border(h, pm)) continue;
+
+
       Oriented_side prev_ori = get(vertex_os, source(h, pm)),
                     next_ori = get(vertex_os, target(next(h, pm), pm));
-      if (prev_ori == ON_ORIENTED_BOUNDARY || next_ori == ON_ORIENTED_BOUNDARY) continue; // skip full edge
-      if (prev_ori!=next_ori) splitted_faces[face(h, pm)].push_back(h); // skip tangency point
+
+
+      splitted_faces[face(h, pm)].push_back(h);
+      // we insert tangency point twice as the vertex will be used twice to split a face (if not a crossing)
+      if (prev_ori==ON_ORIENTED_BOUNDARY || next_ori==ON_ORIENTED_BOUNDARY || prev_ori==next_ori)
+        splitted_faces[face(h, pm)].push_back(h); // skip crossing points
     }
   }
 
@@ -439,14 +445,27 @@ void refine_with_plane(PolygonMesh& pm,
   {
     std::size_t nb_hedges = f_and_hs.second.size();
 
-    CGAL_assertion( nb_hedges%2 ==0 );
+    // filter out faces that are included in the cutting plane (the cut line does not apply)
+    if (at_least_one_on && nb_hedges%2==0)
+    {
+      bool skip=true;
+      for (std::size_t i=0; i<nb_hedges; i+=2)
+        if(f_and_hs.second[i]!=f_and_hs.second[i+1])
+        {
+          skip=false;
+          break;
+        }
+      if (skip) continue;
+    }
 
     visitor.before_subface_creations(f_and_hs.first, pm);
 
     if (nb_hedges==2)
     {
       halfedge_descriptor h1=f_and_hs.second[0], h2=f_and_hs.second[1];
-      CGAL_assertion(next(h1,pm)!=h2 && next(h2,pm)!=h1); // the edge does not already exist
+      if(next(h1,pm)==h2 || next(h2,pm)==h1 || h1==h2) // the edge does not already exist
+        continue;
+
       visitor.before_subface_created(pm);
       halfedge_descriptor res = CGAL::Euler::split_face(h1, h2, pm);
       visitor.after_subface_created(face(h2, pm), pm);
@@ -482,7 +501,6 @@ void refine_with_plane(PolygonMesh& pm,
     else
     {
       // sort hedges to make them match
-      CGAL_assertion(!triangulate);
       // TODO: need mechanism to make it robust even with EPICK
       auto less_hedge = [&pm, vpm](halfedge_descriptor h1, halfedge_descriptor h2)
       {
@@ -490,12 +508,48 @@ void refine_with_plane(PolygonMesh& pm,
       };
       std::sort(f_and_hs.second.begin(), f_and_hs.second.end(), less_hedge);
 
+      // remove duplicated vertex at the beginning and at the end of the sorted list
+      // in case the next/prev edge is fully included (its the entry/exit point of the line
+      // and we don't need twice the vertex in that case)
+      if (f_and_hs.second[0]==f_and_hs.second[1])
+      {
+        halfedge_descriptor h = f_and_hs.second[0];
+        if ( get(vertex_os, source(h, pm))==ON_ORIENTED_BOUNDARY || get(vertex_os, target(next(h, pm), pm))==ON_ORIENTED_BOUNDARY)
+          f_and_hs.second.erase(f_and_hs.second.begin());
+      }
+      if (f_and_hs.second.back()==*std::prev(f_and_hs.second.end(),2))
+      {
+        halfedge_descriptor h = f_and_hs.second.back();
+        if ( get(vertex_os, source(h, pm))==ON_ORIENTED_BOUNDARY || get(vertex_os, target(next(h, pm), pm))==ON_ORIENTED_BOUNDARY)
+          f_and_hs.second.pop_back();
+      }
+
+
+      nb_hedges = f_and_hs.second.size();
+      CGAL_assertion(nb_hedges%2==0);
+      CGAL_assertion(!triangulate || nb_hedges==2);
+
       for (std::size_t i=0; i<nb_hedges; i+=2)
       {
-        halfedge_descriptor h1=f_and_hs.second[i], h2=f_and_hs.second[i+1];
-        CGAL_assertion(next(h1,pm)!=h2 && next(h2,pm)!=h1); // the edge does not already exist
+        halfedge_descriptor h1=f_and_hs.second[i],
+                            h2=f_and_hs.second[i+1],
+                            h3=i+2<nb_hedges?f_and_hs.second[i+2]:boost::graph_traits<PolygonMesh>::null_halfedge();
+
+        if(next(h1,pm)==h2 || next(h2,pm)==h1 || h1==h2) // the edge does not already exist or is an outer tangency
+          continue;
+
+        bool update_h3 = h2==h3;
+
         visitor.before_subface_created(pm);
         halfedge_descriptor res = CGAL::Euler::split_face(h1, h2, pm);
+
+        if (update_h3 && face(f_and_hs.second[i+3], pm)!=face(h3,pm))
+        {
+          CGAL_assertion(target(h3, pm)==target(res,pm));
+          CGAL_assertion(face(f_and_hs.second[i+3], pm)==face(res,pm));
+          f_and_hs.second[i+2]=res;
+        }
+
         if constexpr (has_visitor)
         {
           if (face(h1,pm)!=face(h2,pm))
