@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Mesh_3/include/CGAL/Polyhedral_complex_mesh_domain_3.h $
-// $Id: include/CGAL/Polyhedral_complex_mesh_domain_3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Mesh_3/include/CGAL/Polyhedral_complex_mesh_domain_3.h $
+// $Id: include/CGAL/Polyhedral_complex_mesh_domain_3.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -283,6 +283,11 @@ public:
     return this->BaseBase::construct_initial_points_object();
   }
 
+  void set_borders_detected()
+  {
+    borders_detected_=true;
+  }
+
   void detect_features(FT angle_in_degree,
                        std::vector<Polyhedron_type>& p,
                        const bool dont_protect);//if true, features will not be protected
