@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.1/Stream_lines_2/include/CGAL/Regular_grid_2.h $
-// $Id: include/CGAL/Regular_grid_2.h b26b07a1242 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Stream_lines_2/include/CGAL/Regular_grid_2.h $
+// $Id: include/CGAL/Regular_grid_2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -93,7 +93,7 @@ public:
 
 template <class StreamLinesTraits_2>
 inline
-typename Regular_grid_2<StreamLinesTraits_2>::Geom_traits::Iso_rectangle_2
+typename StreamLinesTraits_2::Iso_rectangle_2
 Regular_grid_2<StreamLinesTraits_2>::bbox() const
 {
   return typename Geom_traits::Iso_rectangle_2(0.0, 0.0,
