@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h $
-// $Id: include/CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h $
+// $Id: include/CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -34,10 +34,9 @@ private:
 
 public:
   typedef typename K::Site_2    Site_2;
-  typedef bool                  result_type;
-  typedef Site_2                argument_type;
+  typedef typename K::Boolean   Boolean;
 
-  bool operator()(const Site_2& p, const Site_2& q) const
+  Boolean operator()(const Site_2& p, const Site_2& q) const
   {
     CGAL_precondition( p.is_segment() && q.is_segment() );
 
