@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_conflict_C2.h $
-// $Id: include/CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_conflict_C2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_conflict_C2.h $
+// $Id: include/CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_conflict_C2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -662,11 +662,8 @@ private:
   //------------------------------------------------------------------------
 
 public:
-  typedef Boolean           result_type;
-  typedef Site_2            argument_type;
-
-  Boolean   operator()(const Site_2& p, const Site_2& q, const Site_2& r,
-                       const Site_2& s, const Site_2& t, Sign sgn) const
+  Boolean operator()(const Site_2& p, const Site_2& q, const Site_2& r,
+                     const Site_2& s, const Site_2& t, Sign sgn) const
   {
     if ( sgn == POSITIVE ) {
       return is_interior_in_conflict_none(p, q, r, s, t, Method_tag());
