@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Arrangement_on_surface_2/include/CGAL/Surface_sweep_2/Arr_basic_insertion_traits_2.h $
-// $Id: include/CGAL/Surface_sweep_2/Arr_basic_insertion_traits_2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Arrangement_on_surface_2/include/CGAL/Surface_sweep_2/Arr_basic_insertion_traits_2.h $
+// $Id: include/CGAL/Surface_sweep_2/Arr_basic_insertion_traits_2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -83,7 +83,7 @@ protected:
   const Gt2* m_base_traits;
 
 public:
-  /*! Constructor. */
+  /*! constructs. */
   Arr_basic_insertion_traits_2(const Gt2& tr) :
     m_base_traits(&tr)
   {}
@@ -214,7 +214,7 @@ public:
     Base_equal_2 m_base_equal;
     Halfedge_handle invalid_he;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -251,11 +251,11 @@ public:
       // vertex to the extended point.
       if (! vh->is_at_open_boundary() && m_base_equal(base_p, vh->point()))
         return (Point_2(base_p, vh));
-      else return (Point_2(base_p));
+      return (Point_2(base_p));
     }
   };
 
-  /*! Obtain a Construct_min_vertex_2 function object */
+  /*! obtains a Construct_min_vertex_2 function object */
   Construct_min_vertex_2 construct_min_vertex_2_object() const
   {
     return (Construct_min_vertex_2
@@ -270,7 +270,7 @@ public:
     Base_equal_2 m_base_equal;
     Halfedge_handle invalid_he;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -308,11 +308,11 @@ public:
       // vertex to the extended point.
       if (! vh->is_at_open_boundary() && m_base_equal(base_p, vh->point()))
         return (Point_2(base_p, vh));
-      else return (Point_2(base_p));
+      return (Point_2(base_p));
     }
   };
 
-  /*! Obtain a Construct_max_vertex_2 function object */
+  /*! obtains a Construct_max_vertex_2 function object */
   Construct_max_vertex_2 construct_max_vertex_2_object() const
   {
     return (Construct_max_vertex_2
@@ -325,7 +325,7 @@ public:
   protected:
     Base_compare_xy_2 m_base_cmp_xy;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -346,7 +346,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_xy_2 function object */
+  /*! obtains a Compare_xy_2 function object */
   Compare_xy_2 compare_xy_2_object() const
   { return (Compare_xy_2(m_base_traits->compare_xy_2_object())); }
 
@@ -357,7 +357,7 @@ public:
   protected:
     Base_compare_y_at_x_2 m_base_cmp_y_at_x;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -375,7 +375,7 @@ public:
     { return (m_base_cmp_y_at_x(p.base(), xcv.base())); }
   };
 
-  /*! Obtain a Compare_y_at_x_2 function object */
+  /*! obtains a Compare_y_at_x_2 function object */
   Compare_y_at_x_2 compare_y_at_x_2_object() const
   { return (Compare_y_at_x_2(m_base_traits->compare_y_at_x_2_object())); }
 
@@ -386,7 +386,7 @@ public:
   protected:
     Base_compare_y_at_x_right_2 m_base_cmp_y_at_x_right;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -405,7 +405,7 @@ public:
     { return (m_base_cmp_y_at_x_right(xcv1.base(), xcv2.base(), p.base())); }
   };
 
-  /*! Obtain a Compare_y_at_x_right_2 function object */
+  /*! obtains a Compare_y_at_x_right_2 function object */
   Compare_y_at_x_right_2 compare_y_at_x_right_2_object() const
   {
     return (Compare_y_at_x_right_2
@@ -419,7 +419,7 @@ public:
   protected:
     Base_equal_2 m_base_eq;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -440,7 +440,7 @@ public:
     { return (m_base_eq(p1.base(), p2.base())); }
   };
 
-  /*! Obtain an `Equal_2` function object */
+  /*! obtains an `Equal_2` function object */
   Equal_2 equal_2_object() const
   { return (Equal_2(m_base_traits->equal_2_object())); }
 
@@ -449,7 +449,7 @@ public:
   protected:
     Base_compare_x_2 m_base_cmp_x;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -464,7 +464,7 @@ public:
     { return (m_base_cmp_x(p1.base(), p2.base())); }
   };
 
-  /*! Obtain a Compare_x_2 function object */
+  /*! obtains a Compare_x_2 function object */
   Compare_x_2 compare_x_2_object() const
   { return (Compare_x_2(m_base_traits->compare_x_2_object())); }
 
@@ -473,7 +473,7 @@ public:
   protected:
     Base_is_vertical_2 m_base_is_vert;
 
-    /*! Constructor.
+    /*! constructs.
      * The constructor is declared private to allow only the functor
      * obtaining function, which is a member of the nesting class,
      * constructing it.
@@ -488,7 +488,7 @@ public:
     { return (m_base_is_vert(xcv.base())); }
   };
 
-  /*! Obtain a Is_vertical_2 function object */
+  /*! obtains a Is_vertical_2 function object */
   Is_vertical_2 is_vertical_2_object() const
   { return (Is_vertical_2(m_base_traits->is_vertical_2_object())); }
 
@@ -502,7 +502,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param tr The base traits class. It must be passed, to handle non
      *           stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -526,7 +526,7 @@ public:
     { return m_base->parameter_space_in_x_2_object()(xcv.base()); }
   };
 
-  /*! Obtain a Parameter_space_in_x_2 function object */
+  /*! obtains a Parameter_space_in_x_2 function object */
   Parameter_space_in_x_2 parameter_space_in_x_2_object() const
   { return Parameter_space_in_x_2(m_base_traits); }
 
@@ -538,7 +538,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param tr The base traits class. It must be passed, to handle non
      *           stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -558,7 +558,7 @@ public:
     { return m_base->is_on_x_identification_2_object()(xcv.base()); }
   };
 
-  /*! Obtain a Is_on_x_identification_2 function object */
+  /*! obtains a Is_on_x_identification_2 function object */
   Is_on_x_identification_2 is_on_x_identification_2_object() const
   { return Is_on_x_identification_2(m_base_traits); }
 
@@ -570,7 +570,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param base The base traits class. It must be passed, to handle non
      *             stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -590,7 +590,7 @@ public:
     { return m_base->compare_y_on_boundary_2_object()(p1.base(), p2.base()); }
   };
 
-  /*! Obtain a Compare_y_on_boundary_2 object
+  /*! obtains a Compare_y_on_boundary_2 object
    */
   Compare_y_on_boundary_2 compare_y_on_boundary_2_object() const
   { return Compare_y_on_boundary_2(m_base_traits); }
@@ -603,7 +603,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param base The base traits class. It must be passed, to handle non
      *             stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -628,7 +628,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_y_near_boundary_2 object
+  /*! obtains a Compare_y_near_boundary_2 object
    */
   Compare_y_near_boundary_2 compare_y_near_boundary_2_object() const
   { return Compare_y_near_boundary_2(m_base_traits); }
@@ -643,7 +643,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param tr The base traits class. It must be passed, to handle non
      *           stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -667,7 +667,7 @@ public:
     { return m_base->parameter_space_in_y_2_object()(xcv.base()); }
   };
 
-  /*! Obtain a Parameter_space_in_y_2 function object */
+  /*! obtains a Parameter_space_in_y_2 function object */
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(m_base_traits); }
 
@@ -679,7 +679,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param tr The base traits class. It must be passed, to handle non
      *           stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -699,7 +699,7 @@ public:
     { return m_base->is_on_y_identification_2_object()(xcv.base()); }
   };
 
-  /*! Obtain a Is_on_y_identification_2 function object */
+  /*! obtains a Is_on_y_identification_2 function object */
   Is_on_y_identification_2 is_on_y_identification_2_object() const
   { return Is_on_y_identification_2(m_base_traits); }
 
@@ -711,7 +711,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param base The base traits class. It must be passed, to handle non
      *             stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -724,13 +724,13 @@ public:
     friend class Arr_basic_insertion_traits_2<GeometryTraits_2, Arrangement_>;
 
   public:
-    /*! Use tag dispatching to avoid compilation errors in case the functor
+    /*! uses tag dispatching to avoid compilation errors in case the functor
      * is not defined
      */
     Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
     { return m_base->compare_x_on_boundary_2_object()(p1.base(), p2.base()); }
 
-    /*! Use tag dispatching to avoid compilation errors in case the functor
+    /*! uses tag dispatching to avoid compilation errors in case the functor
      * is not defined
      */
     Comparison_result operator()(const Point_2& p,
@@ -740,7 +740,7 @@ public:
       return m_base->compare_x_on_boundary_2_object()(p.base(), xcv.base(), ce);
     }
 
-    /*! Use tag dispatching to avoid compilation errors in case the functor
+    /*! uses tag dispatching to avoid compilation errors in case the functor
      * is not defined
      */
     Comparison_result operator()(const X_monotone_curve_2& xcv1,
@@ -753,7 +753,7 @@ public:
     }
   };
 
-  /*! Obtain a Compare_x_on_boundary_2 object
+  /*! obtains a Compare_x_on_boundary_2 object
    */
   Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
   { return Compare_x_on_boundary_2(m_base_traits); }
@@ -766,7 +766,7 @@ public:
     //! The base traits.
     const Gt2* m_base;
 
-    /*! Constructor.
+    /*! constructs.
      * \param base The base traits class. It must be passed, to handle non
      *             stateless traits objects, (which stores data).
      * The constructor is declared private to allow only the functor
@@ -779,7 +779,7 @@ public:
     friend class Arr_basic_insertion_traits_2<GeometryTraits_2, Arrangement_>;
 
   public:
-    /*! Use tag dispatching to avoid compilation errors in case the functor
+    /*! uses tag dispatching to avoid compilation errors in case the functor
      * is not defined
      */
     Comparison_result operator()(const X_monotone_curve_2& xcv1,
@@ -791,12 +791,12 @@ public:
     }
   };
 
-  /*! Obtain a Compare_x_near_boundary_2 object
+  /*! obtains a Compare_x_near_boundary_2 object
    */
   Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
   { return Compare_x_near_boundary_2(m_base_traits); }
 };
 
-} //namespace CGAL
+} // namespace CGAL
 
 #endif
