@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.1/Triangulation_2/include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h $
-// $Id: include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h b26b07a1242 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Triangulation_2/include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h $
+// $Id: include/CGAL/Triangulation_2/internal/Polyline_constraint_hierarchy_2.h 08b27d3db14 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -594,7 +594,7 @@ public:
 
   std::array<Vertex_handle, 2> enclosing_constraint(T vaa, T vbb) const;
 
-  Context context(T va, T vb);
+  Context context(T va, T vb) const;
   size_type number_of_enclosing_constraints(T va, T vb) const;
   Context_iterator contexts_begin(T va, T vb) const;
   Context_iterator contexts_end(T va, T vb) const;
@@ -867,7 +867,7 @@ enclosing_constraint(T vaa, T vbb) const -> std::array<Vertex_handle, 2>
 
 template <class T, class Compare, class Point>
 auto Polyline_constraint_hierarchy_2<T,Compare,Point>::
-context(T va, T vb) -> Context
+context(T va, T vb) const -> Context
 {
   auto [hcit, past] = contexts(va, vb);
   CGAL_assertion(hcit != past); CGAL_USE(past);
