@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/BGL/include/CGAL/boost/graph/Euler_operations.h $
-// $Id: include/CGAL/boost/graph/Euler_operations.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/BGL/include/CGAL/boost/graph/Euler_operations.h $
+// $Id: include/CGAL/boost/graph/Euler_operations.h 08b27d3db14 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -12,10 +12,6 @@
 #ifndef CGAL_EULER_OPERATIONS_H
 #define CGAL_EULER_OPERATIONS_H
 
-#include <stdexcept>
-#include <algorithm>
-#include <vector>
-
 #include <boost/graph/graph_traits.hpp>
 #include <CGAL/boost/graph/properties.h>
 
@@ -27,6 +23,10 @@
 
 #include <boost/container/small_vector.hpp>
 
+#include <algorithm>
+#include <stdexcept>
+#include <vector>
+
 namespace CGAL {
 
 /// \cond SKIP_IN_MANUAL
@@ -136,7 +136,7 @@ join_vertex(typename boost::graph_traits<Graph>::halfedge_descriptor h,
   CGAL_assertion( halfedge(v_to_remove, v, g).first == h );
 
   halfedge_around_vertex_iterator ieb, iee;
-  for(boost::tie(ieb, iee) = halfedges_around_target(hop, g); ieb != iee; ++ieb) {
+  for(std::tie(ieb, iee) = halfedges_around_target(hop, g); ieb != iee; ++ieb) {
     CGAL_assertion( target(*ieb,g) == v_to_remove);
     set_target(*ieb ,v , g);
   }
@@ -615,7 +615,7 @@ bool can_add_face(const VertexRange& vrange, const PMesh& sm)
   for(std::size_t i=0; i < N; ++i){
     halfedge_descriptor hd;
     bool found;
-    boost::tie(hd,found) = halfedge(face[i],face[i+1],sm);
+    std::tie(hd,found) = halfedge(face[i],face[i+1],sm);
     if(found && (! is_border(hd,sm))){
       return false;
     }
@@ -1149,7 +1149,7 @@ void make_hole(typename boost::graph_traits<Graph>::halfedge_descriptor h,
 
   face_descriptor fd = face(h, g);
   halfedge_around_face_iterator hafib, hafie;
-  for(boost::tie(hafib, hafie) = halfedges_around_face(h, g);
+  for(std::tie(hafib, hafie) = halfedges_around_face(h, g);
       hafib != hafie;
       ++hafib){
     CGAL_assertion(! is_border(opposite(*hafib,g),g));
@@ -1361,7 +1361,7 @@ add_vertex_and_face_to_border(typename boost::graph_traits<Graph>::halfedge_desc
   internal::set_border(he2,g);
 
   CGAL::Halfedge_around_face_iterator<Graph> hafib,hafie;
-  for(boost::tie(hafib, hafie) = halfedges_around_face(ohe1, g);
+  for(std::tie(hafib, hafie) = halfedges_around_face(ohe1, g);
       hafib != hafie;
       ++hafib){
     set_face(*hafib, f, g);
@@ -1421,7 +1421,7 @@ add_face_to_border(typename boost::graph_traits<Graph>::halfedge_descriptor h1,
   internal::set_border(newhop, g);
 
   CGAL::Halfedge_around_face_iterator<Graph> hafib,hafie;
-  for(boost::tie(hafib, hafie) = halfedges_around_face(newh, g);
+  for(std::tie(hafib, hafie) = halfedges_around_face(newh, g);
       hafib != hafie;
       ++hafib){
     set_face(*hafib, f, g);
@@ -1458,7 +1458,7 @@ does_satisfy_link_condition(typename boost::graph_traits<Graph>::edge_descriptor
   // The following loop checks the link condition for v0_v1.
   // Specifically, that for every vertex 'k' adjacent to both 'p and 'q', 'pkq' is a face of the mesh.
   //
-  for ( boost::tie(eb1,ee1) = halfedges_around_source(v0,g) ;  eb1 != ee1 ; ++ eb1 )
+  for ( std::tie(eb1,ee1) = halfedges_around_source(v0,g) ;  eb1 != ee1 ; ++ eb1 )
   {
     halfedge_descriptor v0_k = *eb1;
 
@@ -1466,7 +1466,7 @@ does_satisfy_link_condition(typename boost::graph_traits<Graph>::edge_descriptor
     {
       vertex_descriptor k = target(v0_k,g);
 
-      for ( boost::tie(eb2,ee2) =  halfedges_around_source(k,g) ; eb2 != ee2 ; ++ eb2 )
+      for ( std::tie(eb2,ee2) =  halfedges_around_source(k,g) ; eb2 != ee2 ; ++ eb2 )
       {
         halfedge_descriptor k_v1 = *eb2;
 
@@ -1537,16 +1537,17 @@ does_satisfy_link_condition(typename boost::graph_traits<Graph>::edge_descriptor
  * collapses an edge in a graph.
  *
  * \tparam Graph must be a model of `MutableFaceGraph`
+ *
  * Let `h` be the halfedge of `e`, and let `v0` and `v1` be the source and target vertices of `h`.
  * Let `p_h` and `p_o_h` be respectively the edges of `prev(h,g)` and `prev(opposite(h, g), g)`.
  * Let `o_n_h` and `o_n_o_h` be respectively the edges of `opposite(next(h,g))` and `opposite(next(opposite(h, g), g))`.
  *
  * After the collapse of edge `e` the following holds:
  *   - The edge `e` is no longer in `g`.
- *   - The faces incident to edge `e` are no longer in `g`.
+ *   - The triangle faces incident to edge `e` are no longer in `g`.
  *   - `v0` is no longer in `g`.
- *   - If `h` is not a border halfedge, `p_h` is no longer in `g` and is replaced by `o_n_h`.
- *   - If the opposite of `h` is not a border halfedge, `p_o_h` is no longer in `g` and is replaced by `o_n_o_h`.
+ *   - If `h` is part of a triangle face, `p_h` is no longer in `g` and is replaced by `o_n_h`.
+ *   - If the opposite of `h` is part of a triangle face, `p_o_h` is no longer in `g` and is replaced by `o_n_o_h`.
  *   - The halfedges kept in `g` that had `v0` as target and source now have `v1` as target and source, respectively.
  *   - No other incidence information is changed in `g`.
  *
@@ -1575,9 +1576,8 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
   bool lBottomFaceExists      = ! is_border(qp,g);
   bool lTopLeftFaceExists     = lTopFaceExists    && ! is_border(pt,g);
   bool lBottomRightFaceExists = lBottomFaceExists && ! is_border(qb,g);
-
-  CGAL_precondition( !lTopFaceExists    || (lTopFaceExists    && ( degree(target(pt, g), g) > 2 ) ) ) ;
-  CGAL_precondition( !lBottomFaceExists || (lBottomFaceExists && ( degree(target(qb, g), g) > 2 ) ) ) ;
+  bool lBottomIsTriangle       = lBottomFaceExists && is_triangle(qp,g);
+  bool lTopIsTriangle          = lTopFaceExists && is_triangle(pq,g);
 
   vertex_descriptor q = target(pq, g);
   vertex_descriptor p = source(pq, g);
@@ -1585,7 +1585,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
 
   bool lP_Erased = false;
 
-  if ( lTopFaceExists )
+  if ( lTopIsTriangle)
   {
     CGAL_precondition( ! is_border(opposite(pt, g),g) ) ; // p-q-t is a face of the mesh
     if ( lTopLeftFaceExists )
@@ -1612,7 +1612,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
     }
   }
 
-  if ( lBottomFaceExists )
+  if ( lBottomIsTriangle)
   {
     CGAL_precondition( ! is_border(opposite(qb, g),g) ) ; // p-q-b is a face of the mesh
     if ( lBottomRightFaceExists )
@@ -1659,7 +1659,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
  * collapses an edge in a graph having non-collapsable edges.
  *
  * Let `h` be the halfedge of `e`, and let `v0` and `v1` be the source and target vertices of `h`.
- * Collapses the edge `e` replacing it with `v1`, as described in the paragraph above
+ * Collapses the edge `e` replacing it with `v1`, as described in the other overload
  * and guarantees that an edge `e2`, for which `get(edge_is_constrained_map, e2)==true`,
  * is not removed after the collapse.
  *
@@ -1669,14 +1669,14 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
  *
  * \returns vertex `v1`.
  * \pre This function requires `g` to be an oriented 2-manifold with or without boundaries.
- *       Furthermore, the edge `v0v1` must satisfy the link condition, which guarantees that the surface mesh is also 2-manifold after the edge collapse.
- * \pre `get(edge_is_constrained_map, v0v1)==false`.
+ *       Furthermore, the edge `e` must satisfy the link condition, which guarantees that the surface mesh is also 2-manifold after the edge collapse.
+ * \pre `get(edge_is_constrained_map, e)==false`.
  * \pre  `v0` and `v1` are not both incident to a constrained edge.
  */
 
 template<typename Graph, typename EdgeIsConstrainedMap>
 typename boost::graph_traits<Graph>::vertex_descriptor
-collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
+collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor e,
               Graph& g,
               EdgeIsConstrainedMap Edge_is_constrained_map)
 {
@@ -1684,11 +1684,11 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
   typedef typename Traits::vertex_descriptor          vertex_descriptor;
   typedef typename Traits::halfedge_descriptor            halfedge_descriptor;
 
-  CGAL_precondition(is_valid_edge_descriptor(v0v1, g));
-  CGAL_precondition(does_satisfy_link_condition(v0v1,g));
-  CGAL_precondition(!get(Edge_is_constrained_map, v0v1));
+  CGAL_precondition(is_valid_edge_descriptor(e, g));
+  CGAL_precondition(does_satisfy_link_condition(e,g));
+  CGAL_precondition(!get(Edge_is_constrained_map, e));
 
-  halfedge_descriptor pq = halfedge(v0v1,g);
+  halfedge_descriptor pq = halfedge(e,g);
 
   halfedge_descriptor qp = opposite(pq,g);
   halfedge_descriptor pt = opposite(prev(pq,g),g);
@@ -1698,6 +1698,8 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
 
   bool lTopFaceExists         = ! is_border(pq,g) ;
   bool lBottomFaceExists      = ! is_border(qp,g) ;
+  bool lTopIsTriangle          = lTopFaceExists && is_triangle(pq,g);
+  bool lBottomIsTriangle       = lBottomFaceExists && is_triangle(qp,g);
 
   vertex_descriptor q = target(pq,g);
   vertex_descriptor p = source(pq,g);
@@ -1708,7 +1710,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
 
   // If the top facet exists, we need to choose one out of the two edges which one disappears:
   //   p-t if it is not constrained and t-q otherwise
-  if ( lTopFaceExists )
+  if ( lTopIsTriangle )
   {
     if ( !get(Edge_is_constrained_map,edge(pt,g)) )
     {
@@ -1722,7 +1724,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
 
   // If the bottom facet exists, we need to choose one out of the two edges which one disappears:
   //   q-b if it is not constrained and b-p otherwise
-  if ( lBottomFaceExists )
+  if ( lBottomIsTriangle )
   {
     if ( !get(Edge_is_constrained_map,edge(qb,g)) )
     {
@@ -1733,7 +1735,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
     }
   }
 
-  if (lTopFaceExists && lBottomFaceExists)
+  if (lTopIsTriangle && lBottomIsTriangle)
   {
     if ( face(edges_to_erase[0],g) == face(edges_to_erase[1],g)
          && (! is_border(edges_to_erase[0],g)) )
@@ -1780,7 +1782,7 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
   }
   else
   {
-    if (lTopFaceExists)
+    if (lTopIsTriangle)
     {
       if (!(is_border(edges_to_erase[0],g))){
         join_face(edges_to_erase[0],g);
@@ -1795,21 +1797,32 @@ collapse_edge(typename boost::graph_traits<Graph>::edge_descriptor v0v1,
       remove_face(opposite(edges_to_erase[0],g),g);
       return q;
     }
-
-    if (! (is_border(edges_to_erase[0],g))){
-      // q will be removed, swap it with p
-      internal::swap_vertices(p, q, g);
-      join_face(edges_to_erase[0],g);
-      join_vertex(qp,g);
-      return q;
-    }
-    if(!is_border(opposite(next(qp,g),g),g))
+    else
     {
-      // q will be removed, swap it with p
-      internal::swap_vertices(p, q, g);
+      if (lBottomIsTriangle)
+      {
+        if (! (is_border(edges_to_erase[0],g))){
+          // q will be removed, swap it with p
+          internal::swap_vertices(p, q, g);
+          join_face(edges_to_erase[0],g);
+          CGAL_assertion(source(qp,g)==p);
+          join_vertex(qp,g);
+          return q;
+        }
+        if(!is_border(opposite(next(qp,g),g),g))
+        {
+          // q will be removed, swap it with p
+          internal::swap_vertices(p, q, g);
+        }
+        remove_face(opposite(edges_to_erase[0],g),g);
+        return q;
+      }
+      else
+      {
+        join_vertex(pq,g);
+        return q;
+      }
     }
-    remove_face(opposite(edges_to_erase[0],g),g);
-    return q;
   }
 }
 
@@ -1866,10 +1879,95 @@ bool satisfies_link_condition(typename boost::graph_traits<Graph>::edge_descript
 }
 /// \endcond
 #endif
+
+/**
+ * removes the target vertex of `h`, merging its incident edges into a single edge linking
+ * the two vertices adjacent to the vertex being removed.
+ *
+ * \tparam Graph must be a model of `MutableFaceGraph`
+ *
+ * \param h halfedge descriptor
+ * \param g the graph
+ *
+ * \returns an halfedge linking the two vertices adjacent to the vertex being removed.
+ *
+ * \pre `degree(target(h, g), g) == 2`.
+ *
+ * \sa `remove_center_vertex()`
+ */
+
+template <typename Graph>
+typename boost::graph_traits<Graph>::halfedge_descriptor
+remove_degree_2_vertex(const typename boost::graph_traits<Graph>::halfedge_descriptor h,
+                       Graph& g)
+{
+  typedef boost::graph_traits<Graph> Traits;
+  typedef typename Traits::vertex_descriptor   vertex_descriptor;
+  typedef typename Traits::halfedge_descriptor halfedge_descriptor;
+  typedef typename Traits::face_descriptor face_descriptor;
+
+  CGAL_precondition(degree(target(h, g), g) == 2);
+
+  vertex_descriptor v = target(h, g);
+  halfedge_descriptor h1 = h;
+  halfedge_descriptor h2 = opposite(next(h1, g), g);
+
+  if(is_border(h1, g))
+    std::swap(h1, h2);
+
+  vertex_descriptor v1 = source(h1, g);
+  vertex_descriptor v2 = source(h2, g);
+
+  bool exists;
+  halfedge_descriptor huv;
+  std::tie(huv, exists) = halfedge(v1, v2, g);
+
+  if(is_border(h2, g))
+  {
+    CGAL_assertion(!is_border(h1, g));
+
+    if(exists)
+    {
+      Euler::remove_face(h1, g);
+      return huv;
+    }
+    else
+    {
+      halfedge_descriptor oh1 = opposite(h1, g);
+      halfedge_descriptor nnh1 = next(next(h1, g), g);
+      halfedge_descriptor ph2 = prev(h2, g);
+      face_descriptor f1 = face(h1, g);
+
+      set_target(h1, v2, g);
+      set_halfedge(v2, ph2, g);
+      set_next(h1, nnh1, g);
+      set_next(ph2, oh1, g);
+      set_halfedge(f1, h1, g); // in case it was nh1
+
+      remove_edge(edge(h2, g), g);
+      remove_vertex(v, g);
+
+      return h1;
+    }
+  }
+  else
+  {
+    CGAL_assertion(!is_border(h1, g) && !is_border(h2, g));
+
+    halfedge_descriptor ph1 = prev(h1, g);
+    halfedge_descriptor ph2 = prev(h2, g);
+    Euler::remove_center_vertex(h, g);
+
+    if(exists)
+      return huv;
+    else
+      return Euler::split_face(ph1, ph2, g);
+  }
+}
+
 /// @}
 
 } // namespace Euler
-
 } // namespace CGAL
 
 #endif /* CGAL_EULER_OPERATIONS_H */
