@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Cartesian_kernel/include/CGAL/predicates/kernel_ftC2.h $
-// $Id: include/CGAL/predicates/kernel_ftC2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Cartesian_kernel/include/CGAL/predicates/kernel_ftC2.h $
+// $Id: include/CGAL/predicates/kernel_ftC2.h 08b27d3db14 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -421,6 +421,7 @@ typename Same_uncertainty_nt<Angle, FT>::type
 angleC2(const FT &ux, const FT &uy,
         const FT &vx, const FT &vy)
 {
+  typedef typename Same_uncertainty_nt<Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign(ux*vx + uy*vy));
 }
 
@@ -431,6 +432,7 @@ angleC2(const FT &px, const FT &py,
         const FT &qx, const FT &qy,
         const FT &rx, const FT &ry)
 {
+  typedef typename Same_uncertainty_nt<Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-qx)+(py-qy)*(ry-qy)));
 }
 
@@ -442,6 +444,7 @@ angleC2(const FT &px, const FT &py,
         const FT &rx, const FT &ry,
         const FT &sx, const FT &sy)
 {
+  typedef typename Same_uncertainty_nt<Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-sx)+(py-qy)*(ry-sy)));
 }
 
@@ -508,6 +511,7 @@ side_of_bounded_circleC2(const FT &px, const FT &py,
                          const FT &rx, const FT &ry,
                          const FT &tx, const FT &ty)
 {
+  typedef typename Same_uncertainty_nt<Bounded_side, FT>::type Bounded_side;
   return enum_cast<Bounded_side>( side_of_oriented_circleC2(px,py,qx,qy,rx,ry,tx,ty)
                                  * orientationC2(px,py,qx,qy,rx,ry) );
 }
@@ -520,8 +524,8 @@ side_of_bounded_circleC2(const FT &px, const FT &py,
                          const FT &tx, const FT &ty)
 {
   // Returns whether T lies inside or outside the circle which diameter is PQ.
-  return enum_cast<Bounded_side>(
-                      CGAL_NTS compare((tx-px)*(qx-tx), (ty-py)*(ty-qy)) );
+  typedef typename Same_uncertainty_nt<Bounded_side, FT>::type Bounded_side;
+  return enum_cast<Bounded_side>(CGAL_NTS compare((tx-px)*(qx-tx), (ty-py)*(ty-qy)) );
 }
 
 template < class FT >
@@ -630,7 +634,7 @@ side_of_oriented_lineC2(const FT &a, const FT &b, const FT &c,
 }
 
 template <class FT>
-Comparison_result
+typename Compare<FT>::result_type
 compare_power_distanceC2(const FT& px, const FT& py, const FT& pwt,
                          const FT& qx, const FT& qy, const FT& qwt,
                          const FT& rx, const FT& ry)
@@ -643,24 +647,25 @@ compare_power_distanceC2(const FT& px, const FT& py, const FT& pwt,
 
 template <class FT>
 CGAL_KERNEL_MEDIUM_INLINE
-Bounded_side
+typename Same_uncertainty_nt<Bounded_side, FT>::type
 power_side_of_bounded_power_circleC2(const FT &px, const FT &py, const FT &pw,
                                      const FT &qx, const FT &qy, const FT &qw,
                                      const FT &tx, const FT &ty, const FT &tw)
 {
+  typedef typename Same_uncertainty_nt<Bounded_side, FT>::type Bounded_side;
+
   FT dpx = px - qx;
   FT dpy = py - qy;
   FT dtx = tx - qx;
   FT dty = ty - qy;
   FT dpz = CGAL_NTS square(dpx) + CGAL_NTS square(dpy);
 
-  return enum_cast<Bounded_side>
-    (CGAL_NTS sign(-(CGAL_NTS square(dtx) + CGAL_NTS square(dty)-tw+qw)*dpz
+  return enum_cast<Bounded_side>(CGAL_NTS sign(-(CGAL_NTS square(dtx) + CGAL_NTS square(dty)-tw+qw)*dpz
                    +(dpz-pw+qw)*(dpx*dtx+dpy*dty)));
 }
 
 template <class FT>
-Oriented_side
+typename Same_uncertainty_nt<Oriented_side, FT>::type
 power_side_of_oriented_power_circleC2(const FT &px, const FT &py, const FT &pwt,
                                       const FT &qx, const FT &qy, const FT &qwt,
                                       const FT &rx, const FT &ry, const FT &rwt,
@@ -685,7 +690,7 @@ power_side_of_oriented_power_circleC2(const FT &px, const FT &py, const FT &pwt,
 }
 
 template <class FT>
-Oriented_side
+typename Same_uncertainty_nt<Oriented_side, FT>::type
 power_side_of_oriented_power_circleC2(const FT &px, const FT &py, const FT &pwt,
                                       const FT &qx, const FT &qy, const FT &qwt,
                                       const FT &tx, const FT &ty, const FT &twt)
@@ -709,7 +714,7 @@ power_side_of_oriented_power_circleC2(const FT &px, const FT &py, const FT &pwt,
 }
 
 template <class FT>
-Oriented_side
+typename Same_uncertainty_nt<Oriented_side, FT>::type
 circumcenter_oriented_side_of_oriented_segmentC2(const FT& ax,  const FT& ay,
                                                  const FT& bx,  const FT& by,
                                                  const FT& p0x, const FT& p0y,
